@@ -23,6 +23,7 @@ from tencentcloud.redis.v20180412 import models
 class RedisClient(AbstractClient):
     _apiVersion = '2018-04-12'
     _endpoint = 'redis.tencentcloudapi.com'
+    _service = 'redis'
 
 
     def AssociateSecurityGroups(self, request):
@@ -781,6 +782,34 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeInstanceZoneInfo(self, request):
+        """查询Redis节点信息
+
+        :param request: Request instance for DescribeInstanceZoneInfo.
+        :type request: :class:`tencentcloud.redis.v20180412.models.DescribeInstanceZoneInfoRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.DescribeInstanceZoneInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeInstanceZoneInfo", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeInstanceZoneInfoResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeInstances(self, request):
         """查询Redis实例列表
 
